==> haskell-x509-store-1.6.2-11-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-x509-store.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: x509-store
version: 1.6.2
id: x509-store-1.6.2-LSzLIXqmXeE8B2M05GoDcE
key: x509-store-1.6.2-LSzLIXqmXeE8B2M05GoDcE
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-certificate
synopsis: X.509 collection accessing and storing methods
description:
    X.509 collection accessing and storing methods for certificate, crl, exception list
category: Data
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Data.X509.CertificateStore Data.X509.File Data.X509.Memory
abi: 2f0aab9917979c59b6c795b5e7dd52ef
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/x509-store-1.6.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/x509-store-1.6.2
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/x509-store-1.6.2
hs-libraries: HSx509-store-1.6.2-LSzLIXqmXeE8B2M05GoDcE
depends:
    asn1-encoding-0.9.5-6LpwNZB07IgLoHJaUA49xp
    asn1-types-0.3.2-AepJvBtQBYALMchv1dYtY6 base-4.9.0.0
    bytestring-0.10.8.1 containers-0.5.7.1
    cryptonite-0.22-FrA8V8Abapg2T1hBQpVkR5 directory-1.2.6.2
    filepath-1.4.1.0 mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    pem-0.2.2-qPMQP6sZm3HgQEmiBojNt x509-1.6.5-8aDuSjc8BrL9Z8qXCksOe2
haddock-interfaces: /usr/share/doc/haskell-x509-store/html/x509-store.haddock
haddock-html: /usr/share/doc/haskell-x509-store/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-x509-store-1.6.2-12-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-x509-store.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: x509-store
version: 1.6.2
id: x509-store-1.6.2-E7S4A52kym96dCw30G5pZo
key: x509-store-1.6.2-E7S4A52kym96dCw30G5pZo
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-certificate
synopsis: X.509 collection accessing and storing methods
description:
    X.509 collection accessing and storing methods for certificate, crl, exception list
category: Data
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Data.X509.CertificateStore Data.X509.File Data.X509.Memory
abi: 260391e6c0c69a83bfc1a3bc6a5bba3c
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/x509-store-1.6.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/x509-store-1.6.2
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/x509-store-1.6.2
hs-libraries: HSx509-store-1.6.2-E7S4A52kym96dCw30G5pZo
depends:
    asn1-encoding-0.9.5-fiNDlfe7eW4doDPmKz5l
    asn1-types-0.3.2-LxhcJbRPF00K2icDyHXu1r base-4.9.0.0
    bytestring-0.10.8.1 containers-0.5.7.1
    cryptonite-0.22-JqiMjnb5zSBCoWgTNo13Ue directory-1.2.6.2
    filepath-1.4.1.0 mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    pem-0.2.2-qPMQP6sZm3HgQEmiBojNt x509-1.6.5-K5SLEQoLsUh3u9UsbQvMMB
haddock-interfaces: /usr/share/doc/haskell-x509-store/html/x509-store.haddock
haddock-html: /usr/share/doc/haskell-x509-store/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
